"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const parse5 = require("parse5");
const fs_1 = require("./utils/fs");
const html_1 = require("./utils/html");
const ta = parse5.treeAdapters.default;
function default_1(ctx) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (ctx.name !== 'build:before' || ctx.build.engine !== 'cordova') {
            return;
        }
        const indexPath = path.resolve(ctx.project.srcDir, 'index.html');
        const origIndexPath = path.resolve(ctx.project.srcDir, 'index.html.orig');
        const indexContents = yield fs_1.readFile(indexPath);
        const index = parse5.parse(indexContents);
        const rootNode = html_1.findElementByTag(index.childNodes, 'html');
        if (!rootNode) {
            throw new Error('No root node in index.html');
        }
        const namespaceURI = rootNode.namespaceURI;
        const headNode = html_1.findElementByTag(rootNode.childNodes, 'head');
        const bodyNode = html_1.findElementByTag(rootNode.childNodes, 'body');
        if (!headNode || !bodyNode) {
            throw new Error('No head or body node in index.html');
        }
        const cdvattr = { name: 'src', value: 'cordova.js' };
        const scriptNodes = html_1.findElementsByTag([...headNode.childNodes, ...bodyNode.childNodes], 'script');
        const scriptNode = html_1.findElementByAttribute(scriptNodes, cdvattr);
        if (!scriptNode) {
            const el = ta.createElement('script', namespaceURI, [cdvattr]);
            ta.appendChild(headNode, el);
        }
        const serialized = parse5.serialize(index);
        yield Promise.all([
            fs_1.writeFile(origIndexPath, indexContents),
            fs_1.writeFile(indexPath, serialized),
        ]);
    });
}
exports.default = default_1;
